@@ -3,28 +3,19 @@ from hashlib import md5
 from io import BytesIO
 
 import requests
-from fastapi import FastAPI
 import uvicorn
-from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import StreamingResponse
 from cameo_claw.cameo_claw import it_chunk_pl
 
 from pydantic import BaseModel
 
-from cameo_claw.cameo_claw_reuse import pd_read_csv
+from cameo_claw.cameo_claw_reuse import pd_read_csv, fastapi_app, lst_demo_url
 
-app = FastAPI()
-app.add_middleware(CORSMiddleware,
-                   allow_origins=['*'],
-                   allow_credentials=True,
-                   allow_methods=['*'],
-                   allow_headers=['*'])
+app = fastapi_app()
 
 
 class ItemUrlFilter(BaseModel):
-    lst_url: list = [
-        'https://cameo-claw-data.vercel.app/device_21152332479_daily_2022-03-30.csv',
-        'https://cameo-claw-data.vercel.app/device_21152332479_daily_2022-03-31.csv']
+    lst_url: list = lst_demo_url
     target_directory: str = './data/topic_filter/'
     lst_distinct_column: list = ['deviceId', 'localTime', 'sensorId']
     lst_column_match: list = [
@@ -37,7 +28,7 @@ class ItemUrlFilter(BaseModel):
 def it_streaming_pl(i: ItemUrlFilter):
     try:
         yield write_csv_header_to_gz_pl(i)
-        for int_progress, bytes1 in it_chunk_pl(
+        for bytes1 in it_chunk_pl(
                 i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
             if bytes1:
                 yield bytes1
